@@ -92,7 +92,7 @@ class Voice(WBits):
 
         command = 'voice{}.is_playing()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
 
     
